/*
 * Copyright (C) 2014 IG Group (webapisupport@ig.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

var deployTypes = { live: "", dark: "?deal_cluster=dark"};

var actions = {

   authentication_service: {
      name: "Login",
      url: "session",
      restdoc: "",
      requestType: "POST",
      version: "2",
      parameters: {
         post: {
            identifier: {
               displayName: 'Username',
               suggestedValues: [
                  'A1960'
               ]
            },

            password: {
               displayName: 'Password',
               hide: 'true',
               suggestedValues: [
                  '123456'
               ]
            },

            encryptedPassword: {
               type: Boolean,
               displayName: 'Encrypt password'
            },

            vendorKey: {
               displayName: 'Application Key',
               suggestedValues: [
                  '717056F2734F57026BBAC6F65E6C6FD1'
               ]
            }

         }
      }
   },

    authentication_v3_service: {
        name: "Login (OAuth)",
        url: "session",
        restdoc: "",
        requestType: "POST",
        version: "3",
        parameters: {
            post: {
                identifier: {
                    displayName: 'Username',
                    suggestedValues: [
                        'A1960'
                    ]
                },

                password: {
                    displayName: 'Password',
                    hide: 'true',
                    suggestedValues: [
                        '123456'
                    ]
                },

                vendorKey: {
                    displayName: 'Application Key',
                    suggestedValues: [
                        '717056F2734F57026BBAC6F65E6C6FD1'
                    ]
                }
            }
        }
    },

   get_session_v1_service: {
      name: "Session details",
      url: "session",
      restdoc: "",
      requestType: "GET",
      version: "1",
      parameters: {
         query: {
            fetchSessionTokens: {
               displayName: 'Retrieve session tokens',
               suggestedValues: ['true', 'false']
            }
         }
      }
   },

   logout_service: {
      name: "Logout",
      url: "session",
      restdoc: "",
      requestType: "DELETE",
      version: "1",
      parameters: {
      }
   },

   sprint_markets_positions_service: {
      name: "Sprint Markets Positions",
      url: "positions/sprintmarket",
      restdoc: "",
      requestType: "GET",
      version: "1",
      parameters: {
      }
   },

   market_search_service: {
      name: "Search Markets",
      url: "markets",
      restdoc: "",
      requestType: "GET",
      version: "1",
      parameters: {
         query: {
            searchTerm: {
               displayName: 'Search string',
               suggestedValues: [
                  'Crude',
                  'FTSE'
               ]
            }
         }
      }
   },

   browse: {
      name: "Browse Markets",
      url: "marketnavigation",
      restdoc: "",
      requestType: "GET",
      version: "1",
      parameters: {
         url: {
            id: {
               displayName: 'Hierarchy id'
            }
         }
      }
   },

   account_watchlists: {
      name: "Account Watchlists",
      url: "watchlists",
      restdoc: "",
      requestType: "GET",
      version: "1",
      parameters: {
         url: {
            id: {
               displayName: 'Watchlist id',
               suggestedValues: ['Popular Markets']
            }
         }
      }
   },

   create_watchlists: {
      name: "Create Watchlist",
      url: "watchlists",
      restdoc: "",
      requestType: "POST",
      version: "1",
      parameters: {
         post: {
            name: {
               displayName: 'Watchlist Name',
               suggestedValues: ['Another watchlist']
            },
            epics: {
               type: "list",
               displayName: 'Epic',
               suggestedValues: ['KA.D.VOD.DAILY.IP,CS.D.EURUSD.TODAY.IP']
            }
         }
      }
   },

   delete_watchlists: {
      name: "Delete Watchlist",
      url: "watchlists",
      restdoc: "",
      requestType: "DELETE",
      version: "1",
      parameters: {
         url: {
            id: {
               displayName: 'Watchlist Id'
            }
         }
      }
   },

   add_instrument_to_watchlist: {
      name: "Add Instrument",
      url: "watchlists",
      restdoc: "",
      requestType: "PUT",
      version: "1",
      parameters: {
         url: {
            id: {
               displayName: 'Watchlist Id'
            }
         },
         post: {
            epic: {
               displayName: 'Epic'
            }
         }
      }
   },

   remove_instrument_from_watchlist: {
      name: "Remove Instrument",
      url: "watchlists",
      restdoc: "",
      requestType: "DELETE",
      version: "1",
      parameters: {
         url: {
            id: {
               displayName: 'Watchlist Id'
            },
            epic: {
               displayName: 'Epic'
            }
         }
      }
   },

   account_switch: {
      name: "Account Switch",
      url: "session",
      restdoc: "",
      requestType: "PUT",
      version: "1",
      parameters: {
         post: {
            accountId: {
               displayName: 'Account ID'
            },
            defaultAccount: {
               displayName: 'Set as default account',
               suggestedValues: ['true', 'false']
            }
         }
      }
   },

   client_account_list: {
      name: "Account Details",
      url: "accounts",
      restdoc: "",
      requestType: "GET",
      version: "1",
      parameters: {
      }
   },

   get_account_settings: {
      name: "Get Account Settings",
      url: "accounts/preferences",
      restdoc: "",
      requestType: "GET",
      version: "1",
      parameters: {
      }
   },

   update_account_settings: {
      name: "Update Account Settings",
      url: "accounts/preferences",
      restdoc: "",
      requestType: "PUT",
      version: "1",
      parameters: {
         post: {
            trailingStopsEnabled: {
               displayName: "Trailing Stops Enabled",
               suggestedValues: ['true', 'false']
            }
         }
      }
   },

   market_details: {
      name: "Market Details",
      url: "markets",
      restdoc: "",
      requestType: "GET",
      version: "3",
      parameters: {
         url: {
            epic: {
               displayName: 'Epic'
            }
         }
      }
   },

   market_details_multi: {
      name: "Market Details - Multiple epics",
      url: "markets",
      restdoc: "",
      requestType: "GET",
      version: "2",
      parameters: {
         query: {
            epics: {
               displayName: 'Comma separated list of epics'
            },
            filter: {
               displayName: "Filter for the market details response",
               suggestedValues: ['ALL', 'SNAPSHOT_ONLY']
            }
         }
      }
   },

   open_positions_service: {
      name: "Open Positions",
      url: "positions",
      restdoc: "",
      requestType: "GET",
      version: "2",
      parameters: {
      }
   },

   open_position_by_dealid_service: {
      name: "Open Position",
      url: "positions",
      restdoc: "",
      requestType: "GET",
      version: "2",
      parameters: {
         url: {
            dealId: {
               displayName: 'DealId'
            }
         }
      }
   },

   create_position: {
      name: "Create Position",
      url: "positions/otc",
      restdoc: "",
      requestType: "POST",
      version: "2",
      parameters: {
         post: {
            epic: {
               displayName: "Epic"
            },

            expiry: {
               displayName: "Expiry",
               suggestedValues: ["-", "DFB"]
            },

            direction: {
               displayName: "Direction",
               suggestedValues: ['BUY', 'SELL']
            },

            size: {
               displayName: "Order Size",
               suggestedValues: ['1']
            },

            orderType: {
               displayName: "Order Type",
               suggestedValues: ["QUOTE", "MARKET", "LIMIT"]
            },

            timeInForce: {
               displayName: "Time In Force",
               suggestedValues: ["FILL_OR_KILL", "EXECUTE_AND_ELIMINATE"]
            },

            level: {
               displayName: "Order Level"
            },

            guaranteedStop: {
               displayName: "Guaranteed stop",
               suggestedValues: ['true', 'false']
            },

            stopLevel: {
               displayName: "Stop Level"
            },

            stopDistance: {
               displayName: "Stop Distance"
            },

            trailingStop: {
               displayName: "Trailing Stop",
               suggestedValues: ["true", "false"]
            },

            trailingStopIncrement: {
               displayName: "Trailing Stop Increment"
            },

            forceOpen: {
               displayName: "Force Open",
               suggestedValues: ['true', 'false']
            },

            limitLevel: {
               displayName: "Limit Level"
            },

            limitDistance: {
               displayName: "Limit Distance"
            },

            quoteId: {
               displayName: "Quote ID"
            },

            currencyCode: {
               displayName: "Currency Code",
               suggestedValues: ['EUR', 'GBP', 'AUD', 'USD', 'CHF']
            }

         }
      }
   },

   create_sprint_market_position: {
      name: "Create Position",
      url: "positions/sprintmarkets",
      restdoc: "",
      requestType: "POST",
      version: "1",
      parameters: {
         post: {
            epic: {
               displayName: "Epic"
            },

            direction: {
               displayName: "Direction",
               suggestedValues: ['BUY', 'SELL']
            },

            size: {
               displayName: "Order Size",
               suggestedValues: ['30']
            },

             expiryPeriod: {
               displayName: "Expiry Period",
                suggestedValues: ['ONE_MINUTE', 'TWO_MINUTES', 'FIVE_MINUTES', 'TWENTY_MINUTES', 'SIXTY_MINUTES']
            }

         }
      }
   },

    get_sprint_market_positions: {
        name: "Get positions",
        url: "positions/sprintmarkets",
        restdoc: "",
        requestType: "GET",
        version: "2",
        parameters: {
        }
    },

   edit_position: {
      name: "Edit Position",
      url: "positions/otc",
      restdoc: "",
      requestType: "PUT",
      version: "2",
      parameters: {
         url: {
            dealId: {
               displayName: "Deal Id"
            }
         },
         post: {
            stopLevel: {
               displayName: "Stop Level"
            },

            limitLevel: {
               displayName: "Limit Level"
            },

            trailingStop: {
               displayName: "Trailing stop",
               suggestedValues: ['true', 'false']
            },

            trailingStopDistance: {
               displayName: "Trailing stop distance"
            },

            trailingStopIncrement: {
               displayName: "Trailing stop increment"
            }
         }
      }
   },

   close_position: {
      name: "Close Position",
      url: "positions/otc",
      restdoc: "",
      requestType: "DELETE",
      version: "1",
      parameters: {
         post: {
            dealId: {
               displayName: "Deal Id"
            },

            epic: {
               displayName: "Epic"
            },

            expiry: {
               displayName: "Expiry"
            },

            direction: {
               displayName: "Direction",
               suggestedValues: ['BUY', 'SELL']
            },

            size: {
               displayName: "Deal Size",
               suggestedValues: ['1']
            },

            level: {
               displayName: "Closing order Level"
            },

            orderType: {
               displayName: "Order Type",
               suggestedValues: ['MARKET', 'LIMIT', 'QUOTE']
            },

            timeInForce: {
               displayName: "Time In Force",
               suggestedValues: ["FILL_OR_KILL", "EXECUTE_AND_ELIMINATE"]
            },

            quoteId: {
               displayName: "Quote ID"
            }
         }
      }
   },

   working_orders: {
      name: "Working Orders",
      url: "workingorders",
      restdoc: "",
      requestType: "GET",
      version: "2",
      parameters: {
      }
   },

   create_working_order: {
      name: "Create Working Order",
      url: "workingorders/otc",
      restdoc: "",
      requestType: "POST",
      version: "2",
      parameters: {
         post: {
            epic: {
               displayName: "Epic"
            },

            expiry: {
               displayName: "Expiry"
            },

            direction: {
               displayName: "Direction",
               suggestedValues: ['BUY', 'SELL']
            },

            size: {
               displayName: "Order Size",
               suggestedValues: ['1']
            },

            level: {
               displayName: "Order Level"
            },

            forceOpen : {
               displayName: "Force Open",
               suggestedValues: ['true', 'false']
            },

            type: {
               displayName: "Order Type",
               suggestedValues: ['STOP', 'LIMIT']
            },

            currencyCode: {
               displayName: "Currency Code",
               suggestedValues: ['EUR', 'GBP', 'AUD', 'USD']
            },

            timeInForce: {
               displayName: "Time in force",
               suggestedValues: ['GOOD_TILL_CANCELLED', 'GOOD_TILL_DATE']
            },

            goodTillDate: {
               displayName: "Good until date"
            },

            guaranteedStop: {
               displayName: "Guaranteed Stop",
               suggestedValues: ['true', 'false']
            },

            stopLevel: {
               displayName: "Stop Level"
            },

            stopDistance: {
               displayName: "Stop Distance"
            },

            limitLevel: {
               displayName: "Limit Level"
            },

            limitDistance: {
               displayName: "Limit Distance"
            }

         }
      }
   },

   edit_working_order: {
      name: "Edit Working Order",
      url: "workingorders/otc",
      restdoc: "",
      requestType: "PUT",
      version: "2",
      parameters: {
         url: {
            dealId: {
               displayName: "Deal Id"
            }
         },
         post: {
            timeInForce: {
               displayName: "Time in force",
               suggestedValues: ['GOOD_TILL_CANCELLED', 'GOOD_TILL_DATE']
            },

            goodTillDate: {
               displayName: "Good until date"
            },

            stopLevel: {
               displayName: "Stop Level"
            },

            stopDistance: {
               displayName: "Stop Distance"
            },

            limitLevel: {
               displayName: "Limit Level"
            },

            limitDistance: {
               displayName: "Limit Distance"
            },

            type: {
               displayName: "Order Type",
               suggestedValues: ['STOP', 'LIMIT']
            },

            level: {
               displayName: "Order Level"
            }

         }
      }
   },

   delete_working_order: {
      name: "Delete Working Order",
      url: "workingorders/otc",
      restdoc: "",
      requestType: "DELETE",
      version: "2",
      parameters: {
         url: {
            dealId: {
               displayName: "Deal Id"
            }
         }
      }
   },

   confirm: {
      name: "Trade Confirm",
      url: "confirms",
      restdoc: "",
      requestType: "GET",
      version: "1",
      parameters: {
         url: {
            id: {
               displayName: 'Deal Reference',
               suggestedValues: ['DLHJ4KMBHKNL']
            }
         }
      }
   },

   transaction_history: {
      name: "Transaction History",
      url: "history/transactions",
      restdoc: "",
      requestType: "GET",
      version: "2",
      parameters: {
         query: {
            type: {
               displayName: 'Type',
               suggestedValues: ['ALL', 'ALL_DEAL', 'DEPOSIT', 'WITHDRAWAL']
            },
            from: {
               displayName: 'Start date',
               suggestedValues: [
                  '2015-07-21T00:00:00'
               ]
            },
            to: {
               displayName: 'End date',
               suggestedValues: [
                  '2015-07-21T23:59:59'
               ]
            },
            maxSpanSeconds: {
               displayName: 'Period in seconds',
               suggestedValues: ['600']
            },
            pageSize: {
               displayName: 'Page size',
               suggestedValues: ['20']
            },
            pageNumber: {
               displayName: 'Page number',
               suggestedValues: ['1']
            }
         }
      }
   },

   activity_history: {
      name: "Activity History",
      url: "history/activity",
      restdoc: "",
      requestType: "GET",
      version: "3",
      parameters: {
         query: {
            from: {
               displayName: 'Start date',
               suggestedValues: ['2016-05-01T00:00:00']
            },
            to: {
               displayName: 'End date',
               suggestedValues: ['2016-05-31T23:59:59']
            },
            detailed: {
               displayName: 'Show details',
               suggestedValues: ['false']
            },
            dealId: {
               displayName: 'Deal ID'
            },
            filter: {
               displayName: 'Filter'
            },
            pageSize: {
               displayName: 'Page size',
               suggestedValues: ['50']
            }
         }
      }
   },

   price_search: {
      name: "Historic Price Search",
      url: "prices",
      restdoc: "",
      requestType: "GET",
      version: "3",
      parameters: {
         url: {
            epic: {
               displayName: 'Epic',
               suggestedValues: [
                  'IX.D.FTSE.CFD.IP'
               ]
            }
         },
         query: {
            resolution: {
               displayName: 'Resolution',
               suggestedValues: [
                  'SECOND', 'MINUTE', 'MINUTE_2', 'MINUTE_3', 'MINUTE_5', 'MINUTE_10', 'MINUTE_15', 'MINUTE_30', 'HOUR', 'HOUR_2', 'HOUR_3', 'HOUR_4', 'DAY', 'WEEK', 'MONTH'
               ]
            },
            from: {
               displayName: 'Start date',
               suggestedValues: [
                  '2015-07-21T00:00:00'
               ]
            },
            to: {
               displayName: 'End date',
               suggestedValues: [
                  '2015-07-21T23:59:59'
               ]
            },
            max: {
               displayName: 'Max. price points',
               suggestedValues: [
                  '10'
               ]
            },
            pageSize: {
               displayName: 'Page size',
               suggestedValues: ['20']
            },
            pageNumber: {
               displayName: 'Page number',
               suggestedValues: ['1']
            }
         }
      }
   },

   client_sentiment_single: {
      name: "Sentiment",
      url: "clientsentiment",
      restdoc: "",
      requestType: "GET",
      version: "1",
      parameters: {
         url: {
            marketId: {
               displayName: 'Market identifier',
               suggestedValues: [
                  'FT100'
               ]
            }

         }
      }
   },

   client_sentiment_multiple: {
      name: "Sentiment (multiple markets)",
      url: "clientsentiment",
      restdoc: "",
      requestType: "GET",
      version: "1",
      parameters: {
         query: {
            marketIds: {
               displayName: 'Comma separated list of market identifiers',
               suggestedValues: ['FT100,EURUSD']
            }
         }

      }
   },

   client_sentiment_related: {
      name: "Sentiment of Related Markets",
      url: "clientsentiment/related",
      restdoc: "",
      requestType: "GET",
      version: "1",
      parameters: {
         url: {
            marketId: {
               displayName: 'Market',
               suggestedValues: [
                  'FT100'
               ]
            }

         }
      }
   },
   application_list: {
      name: "List Applications",
      url: "operations/application",
      restdoc: "",
      requestType: "GET",
      version: "1",
      parameters: {
      }
   },
   application_disable: {
      name: "Disable Application",
      url: "operations/application/disable",
      restdoc: "",
      requestType: "PUT",
      version: "1",
      parameters: {
      }},
   application_update: {
      name: "Update Application",
      url: "operations/application",
      restdoc: "",
      requestType: "PUT",
      version: "1",
      parameters: {
         post: {
            apiKey: {
               displayName: 'API key'
            },
            status: {
               displayName: 'Status',
               suggestedValues: [
                  'ENABLED', 'DISABLED'
               ]
            },
            allowanceAccountTrading: {
               displayName: 'Account Trading Allowance'
            },
            allowanceAccountOverall: {
               displayName: 'Account Overall Allowance'
            },
            receiveNonApiConfirms: {
               displayName: 'Receive Non-API confirms',
               suggestedValues: ['true', 'false']
            }
         }
      }
   }

};

function Request() {
   this.headers = {"Content-Type": "application/json; charset=UTF-8", "Accept": "application/json; charset=UTF-8"};
   this.body = "";
   this.method = "";
   this.url = "";
   this.version = "";

   this.xhr = null;
   this.nameE = null;		// element
   this.valueE = null;
   this.hname = "";		// header name
   this.hvalue = "";		// header value
}
